These are convenience functions to download, daily or monthly
sea ice concentration data from the whole Antarctic or Arctic.
For a more complete low level function, see cdr().
Usage
cdr_antarctic_monthly(
date_range,
variables = "aice",
version = 5,
file = NULL,
dir = tempdir(),
use_cache = TRUE
)
cdr_antarctic_daily(
date_range,
variables = "aice",
version = 5,
file = NULL,
dir = tempdir(),
use_cache = TRUE
)
cdr_arctic_monthly(
date_range,
variables = "aice",
version = 5,
file = NULL,
dir = tempdir(),
use_cache = TRUE
)
cdr_arctic_daily(
date_range,
variables = "aice",
version = 5,
file = NULL,
dir = tempdir(),
use_cache = TRUE
)Arguments
- date_range
Vector of size two with the start and end dates. Supported formats are:
A Date or POSIXct/POSIXlt object.
A character vector with ISO format dates:
c("2020-01-01", "2020-12-31")A character vector with year-month:
c("2020-01", "2020-06")(expands to first/last day of month).A character vector with year only:
c("2020", "2021")(expands to full year).
- variables
Character vector with the variables to fetch. Valid values are
qaQuality control flag.
stdevSea ice standard deviation.
interpolation_spatialFlag for spatial interpolation.
interpolation_temporalFlag for temporal interpolation.
aice_btSea ice concentration of the Bootstrap method.
aice_ntSea ice concentration of the Nasa Team method.
Although not all variables are available in all versions and all resolutions. The
*_ntand*_btvariables are only available in version 4 and the interpolation flags are only available for daily values.- version
Version of the dataset. Can be 4 or 5.
- file
Character with the file name to use for download. If
NULL, the file name will be constructed by hashing the request URL. Requests consisting in more than one file will append a number.- dir
Directory where to download the file.
- use_cache
Logical indicating whether to not perform the download if the file already exist.
Examples
if (FALSE) { # \dontrun{
cdr_antarctic_monthly(c("2022-01", "2022-01"))
} # }